============
Installation
============

This package can be used by python 2.7, 3.3 and pypi.

Install from the `Cheese shop`_::

    $ pip install json-extensions

Install from the sources_::

    $ pip install git+https://github.com/johnnoone/json-extensions.git


.. _`Cheese shop`: https://pypi.python.org/pypi/json-extensions
.. _sources: https://github.com/johnnoone/json-extensions
